.. _salt-cloud:

==========
Salt Cloud
==========

Getting Started
===============

.. toctree::
    :maxdepth: 3

    Installing salt cloud <install/index>

Using Salt Cloud
================
.. toctree::
    :maxdepth: 3

    Basic <basic>
    Profiles <profiles>
    Maps <map>
    Actions <action>
    Functions <function>

Core Configuration
==================
.. toctree::
    :maxdepth: 3

    Core Configuration <config>

Windows Configuration
=====================
.. toctree::
    :maxdepth: 3

        Windows Configuration <windows>

.. _cloud-provider-specifics:

Cloud Provider Specifics
========================
.. toctree::
    :maxdepth: 3

        Getting Started With Aliyun <aliyun>
        Getting Started With Azure <azure>
        Getting Started With DigitalOcean <digitalocean>
        Getting Started With EC2 <aws>
        Getting Started With GoGrid <gogrid>
        Getting Started With Google Compute Engine <gce>
        Getting Started With HP Cloud <hpcloud>
        Getting Started With Joyent <joyent>
        Getting Started With LXC <lxc>
        Getting Started With Linode <linode>
        Getting Started With OpenStack <openstack>
        Getting Started With Parallels <parallels>
        Getting Started With Proxmox <proxmox>
        Getting Started With Rackspace <rackspace>
        Getting Started With SoftLayer <softlayer>
        Getting Started With Vexxhost <vexxhost>

Miscellaneous Options
=====================
.. toctree::
    :maxdepth: 3

    Miscellaneous <misc>

Troubleshooting Steps
=====================
.. toctree::
    :maxdepth: 3

        Troubleshooting <troubleshooting>

Extending Salt Cloud
====================
.. toctree::
    :maxdepth: 3

    Adding Cloud Providers <cloud>
    Adding OS Support <deploy>

Using Salt Cloud from Salt
==========================
.. toctree::
    :maxdepth: 3

    Using Salt Cloud from Salt <salt>

Feature Comparison
==================
.. toctree::
    :maxdepth: 3

    Features <features>
